@@ -1,10 +1,22 @@
 import re
 from typing import Any, Callable, List, Optional, Pattern, Union
 
-from unidecode import unidecode
-
-from .dynamic_typing import (ComplexType, DDict, DList, DOptional, DUnion, MetaData, ModelPtr, Null, SingleType,
-                             StringSerializable, StringSerializableRegistry, Unknown, registry)
+from .dynamic_typing import (
+    ComplexType,
+    DDict,
+    DList,
+    DOptional,
+    DUnion,
+    MetaData,
+    ModelPtr,
+    Null,
+    SingleType,
+    StringLiteral,
+    StringSerializable,
+    StringSerializableRegistry,
+    Unknown,
+    registry
+)
 
 _static_types = {float, bool, int}
 
@@ -44,12 +56,8 @@ class MetadataGenerator:
         """
         fields = dict()
         for key, value in data.items():
-            # TODO: Check if is 0xC0000005 crash has a place at linux systems
-            # ! _detect_type function can crash at some complex data sets if value is unicode with some characters (maybe German)
-            #   Crash does not produce any useful logs and can occur any time after bad string was processed
-            #   It can be reproduced on real_apis tests (openlibrary API)
             convert_dict = key not in self.dict_keys_fields
-            fields[key] = self._detect_type(value if not isinstance(value, str) else unidecode(value), convert_dict)
+            fields[key] = self._detect_type(value, convert_dict)
         return fields
 
     def _detect_type(self, value, convert_dict=True) -> MetaData:
@@ -108,7 +116,7 @@ class MetadataGenerator:
                 except ValueError:
                     continue
                 return t
-            return str
+            return StringLiteral({value})
 
     def merge_field_sets(self, field_sets: List[MetaData]) -> MetaData:
         """
@@ -188,6 +196,9 @@ class MetadataGenerator:
         elif isinstance(meta, ComplexType):
             # Optimize all nested types
             return meta.replace([self.optimize_type(nested) for nested in meta])
+        elif isinstance(meta, StringLiteral):
+            if meta.overflowed or not meta.literals:
+                return str
         return meta
 
     def _optimize_union(self, t: DUnion):
@@ -199,7 +210,7 @@ class MetadataGenerator:
         str_types: List[Union[type, StringSerializable]] = []
         types_to_merge: List[dict] = []
         list_types: List[DList] = []
-        dict_types: List[DList] = []
+        dict_types: List[DDict] = []
         other_types: List[MetaData] = []
         for item in t.types:
             if isinstance(item, DOptional):
